from ascii_magic import AsciiArt
from ascii_magic.constants import DEFAULT_GEMINI_MODEL

from PIL import Image

from typing import Optional


def quick_test():
    AsciiArt.quick_test()


def from_image(path: str) -> AsciiArt:
    return AsciiArt.from_image(path)


def from_pillow_image(img: Image.Image) -> AsciiArt:
    return AsciiArt.from_pillow_image(img)


def from_url(url: str) -> AsciiArt:
    return AsciiArt.from_url(url)


def from_clipboard() -> AsciiArt:
    return AsciiArt.from_clipboard()


def from_gemini(
    prompt: str,
    api_key: Optional[str] = None,
    model: str = DEFAULT_GEMINI_MODEL,
    debug: bool = False,
) -> AsciiArt:
    return AsciiArt.from_gemini(prompt, model, api_key, debug)


def from_swarmui(
    prompt: str,
    width: int = 1280,
    height: int = 720,
    steps: int = 20,
    raw_input: dict = {},
    server: str = 'http://localhost:7801',
    model: str = 'auto',
    debug: bool = False,
) -> AsciiArt:
    return AsciiArt.from_swarmui(prompt, width, height, steps, raw_input, server, model, debug)



from ascii_magic import AsciiArt


def test_enhance():
    my_art = AsciiArt.from_image('lion.jpg')
    my_art.to_image_file('output_lion_enhance_false.png', enhance_image=False, full_color=True)
    my_art.to_image_file('output_lion_enhance_true.png', enhance_image=True, full_color=True)



from ascii_magic.ascii_art import AsciiArt
from ascii_magic.constants import Front, Back, CHARS_BY_DENSITY, DEFAULT_GEMINI_MODEL
from ascii_magic.functions import (
    quick_test,
    from_image,
    from_pillow_image,
    from_url,
    from_clipboard,
    from_gemini,
    from_swarmui,
)

__all__ = [
    # Main classes
    "AsciiArt",
    "Front",
    "Back",
    # Functions
    "quick_test",
    "from_image",
    "from_pillow_image",
    "from_url",
    "from_clipboard",
    "from_gemini",
    "from_swarmui",
    # Extra stuff
    "CHARS_BY_DENSITY",
    "DEFAULT_GEMINI_MODEL",
]
